@@ -28,8 +28,8 @@
 #include <tqdatetime.h>
 #include <tqregexp.h>
 
-#include <klocale.h>
-#include <kdeversion.h>
+#include <tdelocale.h>
+#include <tdeversion.h>
 #include <kstringhandler.h>
 #include <config.h>
 #include <kdebug.h>
@@ -113,7 +113,7 @@ void InputFilter::parseLine(const TQString& a_newLine)
 
 void InputFilter::parseClientCommand(const TQString &prefix, const TQString &command, const TQStringList &parameterList, const TQString &_trailing)
 {
-    KonversationApplication* konv_app = static_cast<KonversationApplication *>(KApplication::kApplication());
+    KonversationApplication* konv_app = static_cast<KonversationApplication *>(TDEApplication::kApplication());
     Q_ASSERT(konv_app);
     Q_ASSERT(server);
     // Extract nickname from prefix
